@@ -2,7 +2,7 @@
 from __future__ import unicode_literals, absolute_import
 
 from django.contrib.postgres.fields import JSONField
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.db import models
 
 from cuser.models import AbstractCUser
@@ -19,7 +19,7 @@ class User(AbstractCUser):
     faculty = models.BooleanField(default=False, db_index=True)
 
     def get_absolute_url(self):
-        return reverse('users:detail', kwargs={'email': self.email})
+        return reverse('simpl_users_api:user-detail', kwargs={'id': self.pk})
 
     def webhook_payload(self):
         return {
