@@ -5,9 +5,11 @@ from django.conf.urls import include, url
 
 from simpl_users.apis.urls import router as api_router
 
-
 # Our application urls
 urlpatterns = [
-    url(r'^apis/', include(api_router.urls, namespace='simpl_users_api')),
-    url(r'^users/', include('simpl_users.urls', namespace='users')),
+    url(r'^apis/',
+        include(
+            (api_router.urls, 'simpl_users_api'),
+            namespace='simpl_users_api',
+        )),
 ]
